@@ -1,23 +1,23 @@
-// $Id: AppData.h,v 1.60 1998/01/05 20:27:26 zeller Exp $ -*- C++ -*-
+// $Id: AppData.h,v 1.94 1998/06/13 16:29:04 zeller Exp $ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -35,6 +35,7 @@
 
 #include "version.h"
 #include "OnOff.h"
+#include "BindingS.h"
 
 // The DDD application class name
 #define DDD_CLASS_NAME           Ddd_NAME
@@ -49,8 +50,7 @@
 #define XtCDebugger              "Debugger"
 #define XtNdebuggerCommand       "debuggerCommand"
 #define XtCDebuggerCommand       "DebuggerCommand"
-#define XtNtraceDialog           "traceDialog"
-#define XtNtraceShellCommands    "traceShellCommands"
+#define XtNtrace                 "trace"
 #define XtCTrace                 "Trace"
 #define XtNgdbInitCommands       "gdbInitCommands"
 #define XtNgdbSettings           "gdbSettings"
@@ -58,15 +58,32 @@
 #define XtNdbxSettings           "dbxSettings"
 #define XtNxdbInitCommands       "xdbInitCommands"
 #define XtNxdbSettings           "xdbSettings"
+#define XtNjdbInitCommands       "jdbInitCommands"
+#define XtNjdbSettings           "jdbSettings"
 #define XtNrestartCommands       "restartCommands"
 #define XtCInitCommands          "InitCommands"
+#define XtNsourceInitCommands    "sourceInitCommands"
+#define XtCSourceInitCommands    "SourceInitCommands"
 #define XtCSettings              "Settings"
 #define XtNvslPath               "vslPath"
 #define XtCVSLPath               "VSLPath"
 #define XtNvslLibrary            "vslLibrary"
 #define XtCVSLLibrary            "VSLLibrary"
 #define XtNvslDefs               "vslDefs"
+#define XtNvslBaseDefs           "vslBaseDefs"
 #define XtCVSLDefs               "VSLDefs"
+#define XtNdefaultFont           "defaultFont"
+#define XtNvariableWidthFont     "variableWidthFont"
+#define XtNfixedWidthFont        "fixedWidthFont"
+#ifndef XtCFont
+#define XtCFont                  "Font"
+#endif
+#define XtNdefaultFontSize       "defaultFontSize"
+#define XtNvariableWidthFontSize "variableWidthFontSize"
+#define XtNfixedWidthFontSize    "fixedWidthFontSize"
+#define XtCFontSize              "FontSize"
+#define XtNfontSelectCommand     "fontSelectCommand"
+#define XtCFontSelectCommand     "FontSelectCommand"
 #define XtNtabWidth              "tabWidth"
 #define XtCTabWidth              "TabWidth"
 #define XtNlinesAboveCursor      "linesAboveCursor"
@@ -78,6 +95,8 @@
 #define XtCIndent                "Indent"
 #define XtNlineNumberWidth       "lineNumberWidth"
 #define XtCLineNumberWidth       "LineNumberWidth"
+#define XtNsourceEditing         "sourceEditing"
+#define XtCSourceEditing         "SourceEditing"
 #define XtNlineBufferedConsole   "lineBufferredConsole"
 #define XtCLineBuffered          "LineBuffered"
 #define XtNdisplayShortcuts      "displayShortcuts"
@@ -89,15 +108,16 @@
 #define XtCButtons               "Buttons"
 #define XtNlabelDelimiter        "labelDelimiter"
 #define XtCLabelDelimiter        "LabelDelimiter"
-#define XtNtoolBar               "toolBar"
+#define XtNcommandToolBar        "commandToolBar"
+#define XtNcommonToolBar         "commonToolBar"
 #define XtCToolBar               "ToolBar"
 #define XtNseparateDataWindow    "separateDataWindow"
 #define XtNseparateSourceWindow  "separateSourceWindow"
 #define XtNseparateExecWindow    "separateExecWindow"
 #define XtCSeparate              "Separate"
-#define XtNdataWindow            "dataWindow"
-#define XtNsourceWindow          "sourceWindow"
-#define XtNdebuggerConsole       "debuggerConsole"
+#define XtNopenDataWindow        "openDataWindow"
+#define XtNopenSourceWindow      "openSourceWindow"
+#define XtNopenDebuggerConsole   "openDebuggerConsole"
 #ifndef XtCWindow
 #define XtCWindow                "Window"
 #endif
@@ -105,16 +125,14 @@
 #define XtCTermCommand           "TermCommand"
 #define XtNtermType              "termType"
 #define XtCTermType              "TermType"
-#define XtNtermTimeout           "termTimeout"
-#define XtCTermTimeout           "TermTimeout"
 #define XtNuseTTYCommand         "useTTYCommand"
 #define XtCUseTTYCommand         "UseTTYCommand"
-#define XtNtermStartProcess      "termStartProcess"
-#define XtCTermStartProcess      "TermStartProcess"
 #define XtNquestionTimeout       "questionTimeout"
 #define XtCQuestionTimeout       "QuestionTimeout"
 #define XtNsynchronousDebugger   "synchronousDebugger"
 #define XtCSynchronousDebugger   "SynchronousDebugger"
+#define XtNterminateOnEOF        "terminateOnEOF"
+#define XtCTerminateOnEOF        "TerminateOnEOF"
 #define XtNdebuggerHost          "debuggerHost"
 #define XtCDebuggerHost          "DebuggerHost"
 #define XtNdebuggerRHost         "debuggerRHost"
@@ -153,6 +171,11 @@
 #define XtCShowLicense           "ShowLicense"
 #define XtNshowNews              "showNews"
 #define XtCShowNews              "ShowNews"
+#define XtNshowFonts             "showFonts"
+#define XtCShowFonts             "ShowFonts"
+#define XtNroulette              "roulette"
+#define XtNrussianRoulette       "russianRoulette"
+#define XtCRoulette              "Roulette"
 #define XtNcheckConfiguration    "checkConfiguration"
 #define XtCCheckConfiguration    "CheckConfiguration"
 #define XtNprintCommand          "printCommand"
@@ -173,6 +196,8 @@
 #define XtCGroupIconify          "GroupIconify"
 #define XtNuniconifyWhenReady    "uniconifyWhenReady"
 #define XtCUniconifyWhenReady    "UniconifyWhenReady"
+#define XtNtransientDialogs      "transientDialogs"
+#define XtCTransientDialogs      "TransientDialogs"
 #define XtNglobalTabCompletion   "globalTabCompletion"
 #define XtCGlobalTabCompletion   "GlobalTabCompletion"
 #define XtNsaveHistoryOnExit     "saveHistoryOnExit"
@@ -190,6 +215,12 @@
 #define XtCBlockTTYInput         "BlockTTYInput"
 #define XtNdisplayGlyphs         "displayGlyphs"
 #define XtCDisplayGlyphs         "DisplayGlyphs"
+#define XtNmaxGlyphs             "maxGlyphs"
+#define XtCMaxGlyphs             "MaxGlyphs"
+#define XtNcacheGlyphImages      "cacheGlyphImages"
+#define XtCCacheGlyphImages      "CacheGlyphImages"
+#define XtNglyphUpdateDelay      "glyphUpdateDelay"
+#define XtCGlyphUpdateDelay      "GlyphUpdateDelay"
 #define XtNdisplayLineNumbers    "displayLineNumbers"
 #define XtCDisplayLineNumbers    "DisplayLineNumbers"
 #define XtNdisassemble           "disassemble"
@@ -206,8 +237,14 @@
 #define XtNbuttonDocs            "buttonDocs"
 #define XtNvalueDocs             "valueDocs"
 #define XtCDocs                  "Docs"
+#define XtNstartupTips           "startupTips"
+#define XtCStartupTips           "StartupTips"
+#define XtNstartupTipCount       "startupTipCount"
+#define XtCStartupTipCount       "StartupTipCount"
 #define XtNstatusAtBottom        "statusAtBottom"
 #define XtCStatusAtBottom        "StatusAtBottom"
+#define XtNtoolbarsAtBottom      "toolbarsAtBottom"
+#define XtCToolbarsAtBottom      "ToolbarsAtBottom"
 #define XtNmaxDisplayTitleLength "maxDisplayTitleLength"
 #define XtNmaxPopupExprLength    "maxPopupExprLength"
 #define XtNmaxValueTipLength     "maxValueTipLength"
@@ -225,12 +262,22 @@
 #define XtNblinkWhileBusy        "blinkWhileBusy"
 #define XtCBlinkWhileBusy        "BlinkWhileBusy"
 #define XtNbusyBlinkRate         "busyBlinkRate"
-#define XtNungrabMousePointer    "ungrabMousePointer"
-#define XtCUngrabMousePointer    "UngrabMousePointer"
+#define XtNcheckGrabs            "checkGrabs"
+#define XtCCheckGrabs            "CheckGrabs"
+#define XtNcheckGrabDelay        "checkGrabDelay"
+#define XtCCheckGrabDelay        "CheckGrabDelay"
+#define XtNgrabActionDelay       "grabActionDelay"
+#define XtCGrabActionDelay       "GrabActionDelay"
+#define XtNgrabAction            "grabAction"
+#define XtCGrabAction            "GrabAction"
 #define XtNdetectAliases         "detectAliases"
 #define XtCDetectAliases         "DetectAliases"
+#define XtNdeleteAliasDisplays   "deleteAliasDisplays"
+#define XtCDeleteAliasDisplays   "DeleteAliasDisplays"
 #define XtNalign2dArrays         "align2dArrays"
 #define XtCAlign2dArrays         "Align2dArrays"
+#define XtNexpandRepeatedValues  "expandRepeatedValues"
+#define XtCExpandRepeatedValues  "ExpandRepeatedValues"
 #define XtNbumpDisplays          "bumpDisplays"
 #define XtCBumpDisplays          "BumpDisplays"
 #define XtNhideInactiveDisplays  "hideInactiveDisplays"
@@ -247,7 +294,21 @@
 #define XtCStickyTool            "StickyTool"
 #define XtNtoolRightOffset       "toolRightOffset"
 #define XtNtoolTopOffset         "toolTopOffset"
-#define XtCOffset                "Offset"
+#define XtCToolOffset            "ToolOffset"
+#define XtNbuttonImages          "buttonImages"
+#define XtCButtonImages          "ButtonImages"
+#define XtNbuttonCaptions        "buttonCaptions"
+#define XtCButtonCaptions        "ButtonCaptions"
+#define XtNbuttonCaptionGeometry "buttonCaptionGeometry"
+#define XtCButtonCaptionGeometry "ButtonCaptionGeometry"
+#define XtNbuttonImageGeometry   "buttonImageGeometry"
+#define XtCButtonImageGeometry   "ButtonImageGeometry"
+#define XtNflatToolbarButtons    "flatToolbarButtons"
+#define XtNflatDialogButtons     "flatDialogButtons"
+#define XtCFlatButtons           "FlatButtons"
+#define XtNbuttonColorKey        "buttonColorKey"
+#define XtNsplashScreenColorKey  "splashScreenColorKey"
+#define XtCColorKey              "ColorKey"
 #define XtNautoCommands          "autoCommands"
 #define XtCAutoCommands          "AutoCommands"
 #define XtNautoCommandPrefix     "autoCommandPrefix"
@@ -255,10 +316,12 @@
 #define XtNmaxBreakpointNumber   "maxBreakpointNumber"
 #define XtNmaxDisplayNumber      "maxDisplayNumber"
 #define XtCMaxNumber             "MaxNumber"
-#define XtNshowStartupLogo       "showStartupLogo"
-#define XtCShowStartupLogo       "ShowStartupLogo"
-#define XtNcolorIcons            "colorIcons"
-#define XtCColorIcons            "ColorIcons"
+#define XtNsplashScreen          "splashScreen"
+#define XtCSplashScreen          "SplashScreen"
+#define XtNcolorWMIcons          "colorWMIcons"
+#define XtCColorWMIcons          "ColorWMIcons"
+#define XtNcutCopyPasteBindings  "cutCopyPasteBindings"
+#define XtCBindingStyle          "BindingStyle"
 #define XtNlessTifVersion        "lessTifVersion"
 #define XtCLessTifVersion        "LessTifVersion"
 #define XtNdddinitVersion        "dddinitVersion"
@@ -266,129 +329,165 @@
 #define XtCVersion               "Version"
 
 struct AppData {
-    String  session;
-    String  initial_session;
-    String  debugger;
-    String  debugger_command;
-    Boolean trace_dialog;
-    Boolean trace_shell_commands;
-    String  gdb_init_commands;
-    String  gdb_settings;
-    String  dbx_init_commands;
-    String  dbx_settings;
-    String  xdb_init_commands;
-    String  xdb_settings;
-    String  restart_commands;
-    String  vsl_path;
-    String  vsl_library;
-    String  vsl_defs;
-    int     tab_width;
-    int     lines_above_cursor;
-    int     lines_below_cursor;
-    int     indent_source;
-    int     indent_code;
-    int     line_number_width;
-    Boolean line_buffered_console;
-    String  display_shortcuts;
-    String  console_buttons;
-    String  source_buttons;
-    String  data_buttons;
-    String  tool_buttons;
-    String  label_delimiter;
-    Boolean tool_bar;
-    Boolean separate_data_window;
-    Boolean separate_source_window;
-    Boolean separate_exec_window;
-    Boolean data_window;
-    Boolean source_window;
-    Boolean debugger_console;
-    String  term_command;
-    String  term_type;
-    Boolean use_tty_command;
-    String  term_start_process;
-    int     question_timeout;
-    Boolean synchronous_gdb;
-    String  debugger_host;
-    String  debugger_rhost;
-    String  debugger_host_login;
-    String  rhost_init_commands;
-    String  rsh_command;
-    String  list_exec_command;
-    String  list_source_command;
-    String  list_core_command;
-    String  list_dir_command;
-    String  uncompress_command;
-    String  ps_command;
-    String  www_page;
-    String  www_command;
-    Boolean show_invocation;
-    Boolean show_version;
-    Boolean show_configuration;
-    Boolean show_manual;
-    Boolean show_license;
-    Boolean show_news;
-    Boolean check_configuration;
-    String  print_command;
-    String  paper_size;
-    String  edit_command;
-    String  get_core_command;
-    Boolean panned_graph_editor;
-    Boolean find_words_only;
-    Boolean find_case_sensitive;
-    Boolean group_iconify;
-    Boolean uniconify_when_ready;
-    Boolean global_tab_completion;
-    Boolean save_history_on_exit;
-    Boolean cache_source_files;
-    Boolean cache_machine_code;
-    Boolean suppress_warnings;
-    Boolean tty_mode;
-    OnOff   block_tty_input;
-    Boolean full_name_mode;
-    Boolean display_glyphs;
-    Boolean display_line_numbers;
-    Boolean disassemble;
-    int     max_disassemble;
-    Boolean use_source_path;
-    Boolean all_registers;
-    Boolean button_tips;
-    Boolean value_tips;
-    Boolean button_docs;
-    Boolean value_docs;
-    Boolean status_at_bottom;
-    int     max_display_title_length;
-    int     max_popup_expr_length;
-    int     max_value_tip_length;
-    int     max_value_doc_length;
-    int     button_tip_delay;
-    int     value_tip_delay;
-    int     button_doc_delay;
-    int     value_doc_delay;
-    int     clear_doc_delay;
-    int     clear_tip_delay;
-    Boolean blink_while_busy;
-    int     busy_blink_rate;
-    Boolean ungrab_mouse_pointer;
-    Boolean detect_aliases;
-    Boolean align_2d_arrays;
-    Boolean bump_displays;
-    Boolean hide_inactive_displays;
-    int     status_history_size;
-    Boolean verify_buttons;
-    Boolean auto_raise_tool;
-    OnOff   decorate_tool;
-    Boolean sticky_tool;
-    int     tool_right_offset;
-    int     tool_top_offset;
-    Boolean auto_commands;
-    String  auto_command_prefix;
-    int     max_breakpoint_number;
-    int     max_display_number;
-    String  show_startup_logo;
-    Boolean color_icons;
-    int     lesstif_version;
-    String  dddinit_version;
-    String  app_defaults_version;
+    String    session;
+    String    initial_session;
+    String    debugger;
+    String    debugger_command;
+    Boolean   trace;
+    String    gdb_init_commands;
+    String    gdb_settings;
+    String    dbx_init_commands;
+    String    dbx_settings;
+    String    xdb_init_commands;
+    String    xdb_settings;
+    String    jdb_init_commands;
+    String    jdb_settings;
+    String    restart_commands;
+    Boolean   source_init_commands;
+    String    vsl_path;
+    String    vsl_library;
+    String    vsl_defs;
+    String    vsl_base_defs;
+    String    default_font;
+    String    variable_width_font;
+    String    fixed_width_font;
+    Cardinal  default_font_size;
+    Cardinal  variable_width_font_size;
+    Cardinal  fixed_width_font_size;
+    String    font_select_command;
+    Cardinal  tab_width;
+    Cardinal  lines_above_cursor;
+    Cardinal  lines_below_cursor;
+    Cardinal  indent_source;
+    Cardinal  indent_code;
+    Cardinal  line_number_width;
+    Boolean   source_editing;
+    Boolean   line_buffered_console;
+    String    display_shortcuts;
+    String    console_buttons;
+    String    source_buttons;
+    String    data_buttons;
+    String    tool_buttons;
+    String    label_delimiter;
+    Boolean   command_toolbar;
+    Boolean   common_toolbar;
+    Boolean   separate_data_window;
+    Boolean   separate_source_window;
+    Boolean   separate_exec_window;
+    Boolean   data_window;
+    Boolean   source_window;
+    Boolean   debugger_console;
+    String    term_command;
+    String    term_type;
+    Boolean   use_tty_command;
+    int       question_timeout;
+    Boolean   synchronous_gdb;
+    Boolean   terminate_on_eof;
+    String    debugger_host;
+    String    debugger_rhost;
+    String    debugger_host_login;
+    String    rhost_init_commands;
+    String    rsh_command;
+    String    list_exec_command;
+    String    list_source_command;
+    String    list_core_command;
+    String    list_dir_command;
+    String    uncompress_command;
+    String    ps_command;
+    String    www_page;
+    String    www_command;
+    Boolean   show_invocation;
+    Boolean   show_version;
+    Boolean   show_configuration;
+    Boolean   show_manual;
+    Boolean   show_license;
+    Boolean   show_news;
+    Boolean   show_fonts;
+    Boolean   roulette;
+    Boolean   russian_roulette;
+    Boolean   check_configuration;
+    String    print_command;
+    String    paper_size;
+    String    edit_command;
+    String    get_core_command;
+    Boolean   panned_graph_editor;
+    Boolean   find_words_only;
+    Boolean   find_case_sensitive;
+    Boolean   group_iconify;
+    Boolean   uniconify_when_ready;
+    Boolean   transient_dialogs;
+    Boolean   global_tab_completion;
+    Boolean   save_history_on_exit;
+    Boolean   cache_source_files;
+    Boolean   cache_machine_code;
+    Boolean   suppress_warnings;
+    Boolean   tty_mode;
+    OnOff     block_tty_input;
+    Boolean   full_name_mode;
+    Boolean   display_glyphs;
+    Cardinal  max_glyphs;
+    Boolean   cache_glyph_images;
+    Cardinal  glyph_update_delay;
+    Boolean   display_line_numbers;
+    Boolean   disassemble;
+    Cardinal  max_disassemble;
+    Boolean   use_source_path;
+    Boolean   all_registers;
+    Boolean   button_tips;
+    Boolean   value_tips;
+    Boolean   button_docs;
+    Boolean   value_docs;
+    Boolean   startup_tips;
+    int       startup_tip_count;
+    Boolean   status_at_bottom;
+    Boolean   toolbars_at_bottom;
+    Cardinal  max_display_title_length;
+    Cardinal  max_popup_expr_length;
+    Cardinal  max_value_tip_length;
+    Cardinal  max_value_doc_length;
+    Cardinal  button_tip_delay;
+    Cardinal  value_tip_delay;
+    Cardinal  button_doc_delay;
+    Cardinal  value_doc_delay;
+    Cardinal  clear_doc_delay;
+    Cardinal  clear_tip_delay;
+    Boolean   blink_while_busy;
+    Cardinal  busy_blink_rate;
+    Boolean   check_grabs;
+    Cardinal  check_grab_delay;
+    Cardinal  grab_action_delay;
+    String    grab_action;
+    Boolean   detect_aliases;
+    Boolean   delete_alias_displays;
+    Boolean   align_2d_arrays;
+    Boolean   expand_repeated_values;
+    Boolean   bump_displays;
+    Boolean   hide_inactive_displays;
+    Cardinal  status_history_size;
+    Boolean   verify_buttons;
+    Boolean   auto_raise_tool;
+    OnOff     decorate_tool;
+    Boolean   sticky_tool;
+    Position  tool_right_offset;
+    Position  tool_top_offset;
+    Boolean   button_captions;
+    Boolean   button_images;
+    String    button_caption_geometry;
+    String    button_image_geometry;
+    Boolean   flat_toolbar_buttons;
+    Boolean   flat_dialog_buttons;
+    String    button_color_key;
+    String    splash_screen_color_key;
+    Boolean   auto_commands;
+    String    auto_command_prefix;
+    int       max_breakpoint_number;
+    int       max_display_number;
+    Boolean   splash_screen;
+    Boolean   color_wm_icons;
+    BindingStyle cut_copy_paste_bindings;
+    int       lesstif_version;
+    String    dddinit_version;
+    String    app_defaults_version;
 };
 
 extern AppData app_data;
