@@ -1,23 +1,23 @@
-// $Id: ArgField.h,v 1.12 1997/12/15 18:53:25 zeller Exp $
+// $Id: ArgField.h,v 1.15 1998/05/23 13:14:19 zeller Exp $
 // Argument field Implementation
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -82,13 +82,10 @@ public:
 
     string get_string () const;
 
-    void set_string (char* text_ch);
-    void set_string (string s)
-    {
-	set_string((char *)s);
-    }
+    void set_string(string s);
 
-    Widget widget() { return arg_text_field; };
+    Widget text() const { return arg_text_field; };
+    Widget top()  const;
 
     void addHandler (unsigned    type,
 		     HandlerProc proc,
