@@ -1,23 +1,23 @@
-// $Id: DataDisp.h,v 1.65 1998/01/19 16:07:38 zeller Exp $
+// $Id: DataDisp.h,v 1.88 1998/06/11 16:13:47 zeller Exp $
 // Data Display
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -68,6 +68,7 @@
 
 // DDD includes
 #include "ArgField.h"
+#include "Command.h"
 #include "GDBAgent.h"
 #include "GraphEdit.h"
 #include "DispBox.h"
@@ -78,6 +79,15 @@
 extern GDBAgent *gdb;
 extern ArgField *source_arg;
 
+enum DeferMode { 
+    DeferAlways,		// Defer display creation
+    DeferIfNeeded,		// Defer display creation if needed
+    DeferNever			// Create display now
+};
+
+class NewDisplayInfo;
+class DispGraph;
+
 //-----------------------------------------------------------------------------
 class DataDisp {
 
@@ -90,6 +100,7 @@ class DataDisp {
     // Button callbacks
     //-----------------------------------------------------------------------
     static void dereferenceCB           (Widget, XtPointer, XtPointer);
+    static void dereferenceArgCB        (Widget, XtPointer, XtPointer);
     static void toggleDetailCB          (Widget, XtPointer, XtPointer);
     static void toggleRotateCB          (Widget, XtPointer, XtPointer);
     static void toggleDisableCB         (Widget, XtPointer, XtPointer);
@@ -102,8 +113,10 @@ class DataDisp {
     static void showMoreDetailCB        (Widget, XtPointer, XtPointer);
     static void hideDetailCB            (Widget, XtPointer, XtPointer);
     static void dependentCB             (Widget, XtPointer, XtPointer);
+    static void displayArgCB            (Widget, XtPointer, XtPointer);
     static void setCB                   (Widget, XtPointer, XtPointer);
     static void shortcutCB              (Widget, XtPointer, XtPointer);
+    static void deleteArgCB		(Widget, XtPointer, XtPointer);
 
     //-----------------------------------------------------------------------
     // Popup menu callbacks
@@ -158,30 +171,35 @@ class DataDisp {
     //-----------------------------------------------------------------------
 
     static bool lose_selection;
-    static void SelectionLostCB(Widget, XtPointer, XtPointer);
 
     static void set_args(BoxPoint p = BoxPoint(),
 			 SelectionMode mode = SetSelection);
 
-    static void refresh_args();
     static void refresh_display_list(bool silent = false);
 
     static DispValue *selected_value();
     static DispNode  *selected_node();
 
+    static void open_data_window();
+    static void close_data_window();
+
     static DispNode *new_data_node(const string& name, const string& scope,
 				   const string& answer);
     static DispNode *new_user_node(const string& name, const string& scope,
 				   const string& answer);
+    static DispNode *new_deferred_node(const string& expr, const string& scope,
+				       const BoxPoint& pos,
+				       const string& depends_on);
 
-    static int getDispNrAtPoint (BoxPoint point);
+    static int getDispNrAtPoint(BoxPoint point);
 
     static string numbers(IntArray& a);
+    static bool all_display_numbers(IntArray& numbers);
 
     static void show(Widget dialog, int depth, int more);
 
     static Widget create_display_dialog(Widget parent, String name,
-				      class NewDisplayInfo& info);
+					NewDisplayInfo& info);
 
     static void toggle_rotate(DispValue *dv, bool all = false);
 
@@ -212,13 +230,12 @@ class DataDisp {
     static MMDesc node_popup[];
     static MMDesc shortcut_popup1[];
     static MMDesc shortcut_popup2[];
-    static MMDesc graph_cmd_area[];
     static MMDesc display_area[];
     static MMDesc detail_menu[];
     static MMDesc shortcut_menu[];
     static MMDesc rotate_menu[];
 
-    static const int DataDisp::shortcut_items;
+    static const int shortcut_items;
 
 
     // Array of shortcut expressions
@@ -228,49 +245,103 @@ class DataDisp {
     static void add_shortcut_expr(const string& expr);
 
 public:
+    // Menus - public such that we can chain them in a toolbar
+    static MMDesc graph_cmd_area[];
+
     //-----------------------------------------------------------------------
     // Send queries to GDB and process answers
     //-----------------------------------------------------------------------
 
     // Create a new display for DISPLAY_EXPRESSION.
-    // SCOPE is the name of the current function (must match backtrace output)
+    // SCOPE is the name of the current function (must match backtrace
+    // output) or a scope to be reached; see DEFERRED, below.
     // If POS is set, the new display is created at this position.
     // If DEPENDS_ON is set, the new display is made dependent on
-    // DEPENDS_ON (a display number or name)
+    // DEPENDS_ON (a display number or name).
+    // If DEFERRED is set, defer creation until SCOPE is reached.
     // If ORIGIN is set, the last origin is set to ORIGIN.
     static void new_displaySQ(string display_expression,
 			      string scope,
 			      BoxPoint *pos = 0,
 			      string depends_on = "",
+			      DeferMode deferred = DeferAlways,
 			      Widget origin = 0,
-			      bool verbose = true);
+			      bool verbose = true,
+			      bool prompt = true);
 
     // Refresh displays.  Sends `info display' and `display' to GDB.
-    static void refresh_displaySQ(Widget origin = 0, bool verbose = true);
+    static void refresh_displaySQ(Widget origin = 0, 
+				  bool verbose = true,
+				  bool prompt = true);
 
     // Disable displays given in DISPLAY_NRS.  Sends `disable display' to GDB.
-    static void disable_displaySQ(IntArray& display_nrs, bool verbose = true);
+    static void disable_displaySQ(IntArray& display_nrs,
+				  bool verbose = true,
+				  bool prompt = true);
 
     // Enable displays given in DISPLAY_NRS.  Sends `enable display' to GDB.
-    static void enable_displaySQ(IntArray& display_nrs, bool verbose = true);
+    static void enable_displaySQ(IntArray& display_nrs,
+				 bool verbose = true,
+				 bool prompt = true);
 
     // Delete displays given in DISPLAY_NRS.  Sends `delete display' to GDB.
-    static void delete_displaySQ(IntArray& display_nrs, bool verbose = true);
+    static void delete_displaySQ(IntArray& display_nrs,
+				 bool verbose = true,
+				 bool prompt = true);
+
+    // Same, but return the appropriate command
+    static string new_display_cmd(string display_expression,
+				  BoxPoint *pos = 0,
+				  string depends_on = "");
+
+    static string refresh_display_cmd();
+    static string disable_display_cmd(IntArray& display_nrs);
+    static string enable_display_cmd(IntArray& display_nrs);
+    static string delete_display_cmd(IntArray& display_nrs);
+    static string delete_display_cmd(const string& name);
 
     // Same, but use the GDB_COMMAND interface for enqueing commands
     static void new_display(string display_expression,
 			    BoxPoint *pos = 0,
 			    string depends_on = "",
-			    Widget origin = 0);
+			    Widget origin = 0)
+    {
+	gdb_command(new_display_cmd(display_expression, pos, depends_on), 
+		    origin);
+    }
 
-    static void refresh_display(Widget origin = 0);
-    static void disable_display(IntArray& display_nrs);
-    static void enable_display(IntArray& display_nrs);
-    static void delete_display(IntArray& display_nrs);
+    static void refresh_display(Widget origin = 0)
+    {
+	gdb_command(refresh_display_cmd(), origin);
+    }
 
-    // Process 'info display' output in INFO_DISPLAY_ANSWER.  Deletes
-    // displays if needed.
-    static void process_info_display (string& info_display_answer);
+    static void disable_display(IntArray& display_nrs, Widget origin = 0)
+    {
+	if (display_nrs.size() > 0)
+	    gdb_command(disable_display_cmd(display_nrs), origin);
+    }
+
+    static void enable_display(IntArray& display_nrs, Widget origin = 0)
+    {
+	if (display_nrs.size() > 0)
+	    gdb_command(enable_display_cmd(display_nrs), origin);
+    }
+
+    static void delete_display(IntArray& display_nrs, Widget origin = 0)
+    {
+	if (display_nrs.size() > 0)
+	    gdb_command(delete_display_cmd(display_nrs), origin);
+    }
+
+    static void delete_display(const string& name, Widget origin = 0)
+    {
+	gdb_command(delete_display_cmd(name), origin);
+    }
+
+    // Process 'info display' output in INFO_DISPLAY_ANSWER.  If
+    // DEFER_DELETED is set, defer displays that have been deleted.
+    static void process_info_display (string& info_display_answer, 
+				      bool defer_deleted = true);
 
     // Process `display' output in DISPLAY_ANSWER.  Remaining
     // (non-display) output is returned.  If DISABLING_OCCURRED is set
@@ -285,6 +356,10 @@ public:
     // Process data output in ANSWERS.
     static void process_addr(StringArray& answers);
 
+    // Process current scope
+    static void process_scope(const string& scope);
+    static bool need_scope();
+
     // Set shortcut menu to expressions EXPRS
     static void set_shortcut_menu(const StringArray& exprs,
 				  const StringArray& labels);
@@ -293,6 +368,9 @@ public:
     static void get_shortcut_menu(StringArray& exprs,
 				  StringArray& labels);
 
+    // Refresh argument buttons
+    static void refresh_args(bool update_arg = false);
+
 private:
     // Call me back again
     static void again_new_displaySQ (XtPointer client_data, XtIntervalId *id);
@@ -317,8 +395,10 @@ private:
     static void enable_displayOQC    (const string& answer, void* data);
     static void delete_displayOQC    (const string& answer, void* data);
 
+    static void deletion_done(IntArray& display_nrs, bool do_prompt);
+
     static void add_aliases(IntArray& a);
-    static void sort_and_check(IntArray& a);
+    static bool sort_and_check(IntArray& a);
 
     static void select_with_all_descendants(GraphNode *node);
     static void select_with_all_ancestors(GraphNode *node);
@@ -329,13 +409,14 @@ private:
     //-----------------------------------------------------------------------
     // Data
     //-----------------------------------------------------------------------
-    static class DispGraph *disp_graph;
+    static DispGraph *disp_graph;
     static Delay *delay;
     static Widget last_origin;
     static Time last_select_time;
     static int next_ddd_display_number;
     static int next_gdb_display_number;
     static bool detect_aliases;
+    static bool arg_needs_update;
 
     static Widget graph_popup_w;
     static Widget node_popup_w;
@@ -394,14 +475,12 @@ public:
     static bool bump_displays;
 
     // Constructor
-    DataDisp (XtAppContext app_context,
-	      Widget       parent,
-	      String       vsl_path,         // from app_data
-	      String       vsl_library,      // from app_data
-	      String       vsl_defs,         // from app_data
-	      bool         panned);          // from app_data
+    DataDisp(Widget parent);
 
-    int count_data_displays() const;
+    void create_shells();
+
+    static int count_data_displays();
+    static void get_all_display_numbers(IntArray& numbers);
     static void refresh_graph_edit (bool silent = false);
     static Widget graph_form() { return graph_form_w; }
 
@@ -458,6 +537,12 @@ public:
 
     // Reset all
     static void reset();
+
+    // True if the selection was lost
+    static void SelectionLostCB(Widget = 0, XtPointer = 0, XtPointer = 0);
+
+    // Get number of display NAME
+    static int display_number(const string& name, bool verbose = false);
 };
 
 inline bool DataDisp::get_selection(ostream& os, bool include_position)
