@@ -1,23 +1,23 @@
-// $Id: DispValue.h,v 1.19 1998/01/12 19:09:59 zeller Exp $
+// $Id: DispValue.h,v 1.23 1998/06/09 07:35:57 zeller Exp $
 // Read and store type and value of a displayed expression
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -43,7 +43,11 @@
 #include "value-read.h"
 #include "StringSA.h"
 
-//-----------------------------------------------------------------------------
+class SimpleDispValue;
+class PointerDispValue;
+class ArrayDispValue;
+class StructOrClassDispValue;
+
 class DispValue {
     DispValueType mytype;
     DispValue*    myparent;
@@ -51,15 +55,17 @@ class DispValue {
     bool          myexpanded;
     string        myfull_name;
     string        print_name;   // Name relative to MYPARENT
+    string        myaddr;	// Address as found
     bool          changed;
+    int           myrepeats;	// Number of repetitions
 
     union {
-	class SimpleDispValue*        simple;    // mytype == Simple
-	class PointerDispValue*       pointer;   // mytype == Pointer
-	class ArrayDispValue*         array;     // mytype == Array
-	class StructOrClassDispValue* str_or_cl; // mytype == StructOrClass
-				                 // or mytype == BaseClass
-				                 // or mytype == Reference
+	SimpleDispValue*        simple;    // mytype == Simple
+	PointerDispValue*       pointer;   // mytype == Pointer
+	ArrayDispValue*         array;     // mytype == Array
+	StructOrClassDispValue* str_or_cl; // mytype == StructOrClass
+				           // or mytype == BaseClass
+                                           // or mytype == Reference
     } v;
 
     // Initialize from VALUE.  If TYPE is given, use TYPE as type
@@ -85,7 +91,10 @@ protected:
     void _collapse()  { myexpanded = false; }
 
 public:
-    // The DispValue type is determined from VALUE
+    // Global settings
+    static bool expand_repeated_values;
+
+    // The DispValue type and address are determined from VALUE
     DispValue (DispValue* parent, 
 	       int        depth,
 	       string&    value,
@@ -105,11 +114,14 @@ public:
     DispValueType type()       const { return mytype; }
     DispValue*    parent()     const { return myparent; }
     int           depth()      const { return mydepth; }
+    int           repeats()    const { return myrepeats; }
     const string& full_name()  const { return myfull_name; }
     const string& name()       const { return print_name; }
+    const string& addr()       const { return myaddr; }
 
     DispValue*&   parent()     { return myparent; }
     int&          depth()      { return mydepth; }
+    int&          repeats()    { return myrepeats; }
     string&       full_name()  { return myfull_name; }
     string&       name()       { return print_name; }
 
