@@ -1,23 +1,23 @@
-// $Id: GDBAgent.h,v 1.71 1998/01/23 18:30:32 zeller Exp $
+// $Id: GDBAgent.h,v 1.93 1998/06/14 12:38:47 zeller Exp $
 // Communicate with separate GDB process
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -58,7 +58,7 @@
 // Debugger types
 //-----------------------------------------------------------------------------
 
-enum DebuggerType { GDB, DBX, XDB };
+enum DebuggerType { GDB, DBX, XDB, JDB };
 
 
 //-----------------------------------------------------------------------------
@@ -71,12 +71,26 @@ enum DebuggerType { GDB, DBX, XDB };
 
 enum ProgramLanguage { 
     LANGUAGE_C,			// C-like: C, C++
-    LANGUAGE_PASCAL,		// Pascal-like: Pascal, Modula, Ada
+    LANGUAGE_JAVA,		// Java, as supported by GDB.
+    LANGUAGE_PASCAL,		// Pascal-like: Pascal, Modula...
+    LANGUAGE_ADA,		// Ada (GNAT), as supported by GDB
     LANGUAGE_CHILL,		// Chill, as supported by GDB.
     LANGUAGE_FORTRAN,		// FORTRAN, as supported by GDB.
     LANGUAGE_OTHER		// Others
 };
 
+//-----------------------------------------------------------------------------
+// Watch modes
+//-----------------------------------------------------------------------------
+
+typedef int WatchMode;
+
+const int WATCH_CHANGE = 1;	// break if value changes
+const int WATCH_READ   = 2;	// break if value is read
+const int WATCH_WRITE  = 4;	// break if value is written
+
+const int WATCH_ACCESS = WATCH_READ | WATCH_WRITE; // shorthand
+
 //-----------------------------------------------------------------------------
 // Procedure types.
 //-----------------------------------------------------------------------------
@@ -115,7 +129,9 @@ const unsigned ReadyForCmd      = ReadyForQuestion + 1;
 const unsigned LanguageChanged  = ReadyForCmd + 1;
 const unsigned ReplyRequired    = LanguageChanged + 1;
 const unsigned EchoDetected     = ReplyRequired + 1;
-const unsigned GDBAgent_NTypes  = EchoDetected + 1;
+const unsigned AsyncAnswer      = EchoDetected + 1;
+const unsigned Recording        = AsyncAnswer + 1;
+const unsigned GDBAgent_NTypes  = Recording + 1;
 
 // Handler info
 struct ReplyRequiredInfo {
@@ -164,18 +180,19 @@ private:
     bool _has_make_command;
     bool _has_jump_command;
     bool _has_regs_command;
+    WatchMode _has_watch_command;
     bool _has_named_values;
     bool _has_when_command;
     bool _has_when_semicolon;
-    bool _has_delete_comma;
+    bool _wants_delete_comma;
     bool _has_err_redirection;
     bool _has_givenfile_command;
     bool _has_cont_sig_command;
 
     ProgramLanguage _program_language; // Current program language
 
-    bool _trace_dialog;		// True if dialog is to be traced
     bool _verbatim;		// True if in verbatim mode
+    bool _recording;		// True if we are recording commands
     bool _detect_echos;		// True if echos are to be detected
 
     string last_prompt;		// Last prompt received
@@ -328,6 +345,14 @@ public:
     bool has_regs_command() const      { return _has_regs_command; }
     bool has_regs_command(bool val)    { return _has_regs_command = val; }
 
+    // Non-zero if debugger has `watch' command; also indicates
+    // `watch' capabilities
+    WatchMode has_watch_command() const { return _has_watch_command; }
+    WatchMode has_watch_command(WatchMode val)
+    { 
+	return _has_watch_command = val;
+    }
+
     // True if debugger issues `NAME = VALUE' upon `print' commands
     bool has_named_values() const      { return _has_named_values; }
     bool has_named_values(bool val)    { return _has_named_values = val; }
@@ -341,8 +366,8 @@ public:
     bool has_when_semicolon(bool val)  { return _has_when_semicolon = val; }
 
     // True if debugger wants events separated by `,'
-    bool has_delete_comma() const      { return _has_delete_comma; }
-    bool has_delete_comma(bool val)    { return _has_delete_comma = val; }
+    bool wants_delete_comma() const      { return _wants_delete_comma; }
+    bool wants_delete_comma(bool val)    { return _wants_delete_comma = val; }
 
     // True if debugger has stderr redirection using `>&'
     bool has_err_redirection() const   { return _has_err_redirection; }
@@ -394,14 +419,175 @@ public:
 	return type() == GDB;
     }
 
-    // True if debugger dialog is traced on clog
-    bool trace_dialog() const    { return _trace_dialog; }
-    bool trace_dialog(bool val);
+    // True if debugger can delete breakpoints by number
+    bool has_delete_command() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger has volatile breakpoints (i.e. breakpoints may
+    // change at any time)
+    bool has_volatile_breakpoints() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports I/O redirection
+    bool has_redirection() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports assignments redirection
+    bool has_assign_command() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports calling system functions
+    bool has_system_calls() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports loading and examining executables
+    bool has_exec_files() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports loading and examining classes
+    bool has_classes() const
+    {
+	return type() == JDB;
+    }
+
+    // True if debugger supports loading and examining core files
+    bool has_core_files() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports separate processes (attach, detach)
+    bool has_processes() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports `cd'
+    bool has_cd_command() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports `shell'
+    bool has_shell_command() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger supports temporary breakpoints
+    bool has_temporary_breakpoints() const
+    {
+	return type() == GDB || type() == XDB || has_when_command();
+    }
+
+    // True if debugger supports breakpoint conditions
+    bool has_breakpoint_conditions() const
+    {
+	return type() == GDB || type() == XDB || type() == DBX;
+    }
+
+    // True if debugger has typed pointers, as in `(TYPE)0x0'
+    bool has_typed_pointers() const
+    {
+	return type() == GDB || type() == JDB;
+    }
+
+    // True if debugger has typed structs, as in `(TYPE)0x1234 { ... }'
+    bool has_typed_structs() const
+    {
+	return type() == JDB;
+    }
+
+    // True if debugger uses `(scalar = ...)' for out-of-range enumerations
+    bool has_scalars() const
+    {
+	return type() == DBX;
+    }
+
+    // True if debugger can use quotes for complex expressions
+    bool has_quotes() const
+    {
+	return type() == GDB;
+    }
+
+    // True if `display X' automatically prints X
+    bool display_prints_values() const
+    {
+	return type() == GDB;
+    }
+
+    // True if debugger can enable displays
+    bool has_enable_display_command() const
+    {
+	return type() == GDB;
+    }
+    bool has_disable_display_command() const
+    {
+	return has_enable_display_command();
+    }
+
+    // True if debugger has numbered displays
+    bool has_numbered_displays()
+    {
+	return type() == GDB;
+    }
+
+    // True if debugger wants displays separated by `,'
+    bool wants_display_comma() const
+    {
+	return type() == DBX;
+    }
+
+    // True if debugger has `info displays' command
+    bool has_info_display_command() const
+    {
+	return display_command() != "";
+    }
+
+    // True if `undisplay' redisplays remaining values
+    bool has_redisplaying_undisplay() const
+    {
+	return type() == DBX;
+    }
+
+    // True if debugger supports breakpoint conditions
+    bool has_conditions() const
+    {
+	return has_condition_command() || type() != JDB;
+    }
+
+    // True if debugger can disable breakpoints
+    bool can_disable() const
+    {
+	return has_disable_command() || has_conditions();
+    }
+
+    // True if debugger can enable breakpoints
+    bool can_enable() const
+    {
+	return has_enable_command() || has_conditions();
+    }
 
     // True if DBX output is to be processed verbatim
     bool verbatim() const        { return _verbatim; }
     bool verbatim(bool val)      { return _verbatim = val; }
 
+    // True if we are recording commands
+    bool recording() const         { return _recording; }
+    bool recording(bool val);
+
     // True if checking for echos
     bool detect_echos() const        { return _detect_echos; }
     bool detect_echos(bool val)      { return _detect_echos = val; }
@@ -422,15 +608,18 @@ public:
     string whatis_command(string expr) const;       // GDB: "whatis EXPR"
     string dereferenced_expr(string expr) const;    // GDB: "*EXPR"
     string address_expr(string expr) const;         // GDB: "&EXPR"
-    string index_expr(string expr, int index) const; // GDB: "EXPR[INDEX]"
+    string index_expr(string expr, string index) const; // GDB: "EXPR[INDEX]"
     int default_index_base() const;                 // GDB: 0 in C, else 1
     string info_locals_command() const;	            // GDB: "info locals"
     string info_args_command() const;	            // GDB: "info args"
+    string info_display_command() const;	    // GDB: "info display"
     string disassemble_command(string start, string end = "") const;
                                                 // GDB: "disassemble START END"
     string make_command(string target) const;       // GDB: "make TARGET"
     string jump_command(string pc) const;           // GDB: "jump PC"
     string regs_command(bool all = true) const;	    // GDB: "info registers"
+    string watch_command(string expr, WatchMode w = WATCH_CHANGE) const;
+				                    // GDB: "watch EXPR"
     string kill_command() const;                    // GDB: "kill"
     string enable_command(string bp = "") const;    // GDB: "enable BP"
     string disable_command(string bp = "") const;   // GDB: "disable BP"
@@ -442,6 +631,7 @@ public:
     string shell_command(string cmd) const;	    // GDB: "shell CMD"
     string debug_command(string program = "") const; // GDB: "file PROGRAM"
     string signal_command(int sig) const;           // GDB: "signal SIG"
+    string nop_command(string comment = "") const;  // GDB: "# comment"
 
     // Default history file
     string history_file() const;                    // GDB: "~/.gdb_history"
