@@ -1,23 +1,23 @@
-// $Id: GraphEditP.h,v 1.16 1998/01/02 13:51:31 zeller Exp $
+// $Id: GraphEditP.h,v 1.18 1998/05/04 17:24:48 zeller Exp $
 // GraphEdit Widget -- private interface
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -114,6 +114,10 @@ typedef struct _GraphEditPart {
     Dimension extraWidth;	// Additional width (in pixels)
     Dimension extraHeight;	// Additional height (in pixels)
 
+    // Requested sizes; for panner and scrollbar creation only
+    Dimension requestedWidth;	// Requested width (in pixels)
+    Dimension requestedHeight;	// Requested height (in pixels)
+
     // Pixmaps
     Pixmap selectTile;		// Tile to apply when node is selected
 
