@@ -1,23 +1,23 @@
-// $Id: HelpCB.h,v 1.21 1997/10/03 10:38:12 zeller Exp $  -*- C++ -*-
+// $Id: HelpCB.h,v 1.25 1998/04/16 13:43:10 zeller Exp $  -*- C++ -*-
 // Interactive Help Callbacks
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -61,6 +61,11 @@
 extern void HelpOnContextCB(Widget widget, XtPointer client_data, 
 			    XtPointer call_data);
 
+// Call help on context on the widget that got the help key.
+// May be used in a menu entry "Help On Item".
+extern void HelpOnItemCB(Widget widget, XtPointer client_data, 
+			 XtPointer call_data);
+
 // Call help on current shell window.
 // May be used in a menu entry "Help On Window".
 extern void HelpOnWindowCB(Widget widget, XtPointer client_data, 
@@ -144,8 +149,12 @@ extern XmTextPosition (*TextPosOfEvent)(Widget widget, XEvent *event);
 // Hook for displaying documentation
 extern void (*DisplayDocumentation)(const MString& doc);
 
-// Pixmap to display at ``help on version''
-extern Pixmap (*helpOnVersionPixmapProc)(Widget w);
+// Hook before help on context
+extern void (*PreHelpOnContextHook)(Widget w, XtPointer client_data, 
+				    XtPointer call_data);
+
+// Hook after help on item
+extern void (*PostHelpOnItemHook)(Widget item);
 
 // Additional text to display at ``help on version''
 extern MString helpOnVersionExtraText;
