@@ -1,24 +1,24 @@
-// $Id: SourceView.h,v 1.88 1998/01/02 10:56:22 zeller Exp $
+// $Id: SourceView.h,v 1.130 1998/06/14 14:54:39 zeller Exp $
 // View the Source.
 
 // Copyright (C) 1995-1997 Technische Universitaet Braunschweig, Germany.
 // Written by Dorothea Luetkehaus <luetke@ips.cs.tu-bs.de>
-// and Andreas Zeller (zeller@ips.cs.tu-bs.de).
+// and Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -75,14 +75,14 @@
 extern GDBAgent* gdb;
 extern ArgField* source_arg;
 
-
-// Maximum number of simultaneous glyphs on the screen
-#define MAX_GLYPHS 20
+struct BreakpointPropertiesInfo;
 
 //-----------------------------------------------------------------------------
 class SourceView {
     static void add_to_history(const string& file_name, int line);
     static void add_to_history(const string& address);
+    static void add_current_to_history();
+
     static void goto_entry(string entry);
 
     static void set_source_argCB         (Widget, XtPointer, XtPointer);
@@ -99,8 +99,10 @@ class SourceView {
 
     static void text_popup_printCB       (Widget, XtPointer, XtPointer);
     static void text_popup_dispCB        (Widget, XtPointer, XtPointer);
+    static void text_popup_watchCB       (Widget, XtPointer, XtPointer);
     static void text_popup_print_refCB   (Widget, XtPointer, XtPointer);
     static void text_popup_disp_refCB    (Widget, XtPointer, XtPointer);
+    static void text_popup_watch_refCB   (Widget, XtPointer, XtPointer);
     static void text_popup_whatisCB      (Widget, XtPointer, XtPointer);
     static void text_popup_lookupCB      (Widget, XtPointer, XtPointer);
     static void text_popup_breakCB       (Widget, XtPointer, XtPointer);
@@ -109,20 +111,34 @@ class SourceView {
     static void NewBreakpointDCB         (Widget, XtPointer, XtPointer);
     static void NewBreakpointCB          (Widget, XtPointer, XtPointer);
 
+    static void NewWatchpointDCB         (Widget, XtPointer, XtPointer);
+    static void NewWatchpointCB          (Widget, XtPointer, XtPointer);
+
     static void LookupBreakpointCB       (Widget, XtPointer, XtPointer);
+    static void PrintWatchpointCB        (Widget, XtPointer, XtPointer);
     static void BreakpointCmdCB          (Widget, XtPointer, XtPointer);
 
-    static void EditBreakpointIgnoreCountDCB (Widget, XtPointer, XtPointer);
-    static void EditBreakpointIgnoreCountCB  (Widget, XtPointer, XtPointer);
-    static void EditBreakpointConditionDCB   (Widget, XtPointer, XtPointer);
-    static void EditBreakpointConditionCB    (Widget, XtPointer, XtPointer);
+    static void EditBreakpointPropertiesCB (Widget, XtPointer, XtPointer);
+    static void SetBreakpointIgnoreCountCB (Widget, XtPointer, XtPointer);
+    static void SetBreakpointConditionCB   (Widget, XtPointer, XtPointer);
+    static void EnableBreakpointsCB        (Widget, XtPointer, XtPointer);
+    static void DisableBreakpointsCB       (Widget, XtPointer, XtPointer);
+    static void MakeBreakpointsTempCB      (Widget, XtPointer, XtPointer);
+    static void DeleteBreakpointsCB        (Widget, XtPointer, XtPointer);
+    static void RecordBreakpointCommandsCB (Widget, XtPointer, XtPointer);
+    static void EndBreakpointCommandsCB    (Widget, XtPointer, XtPointer);
+    static void EditBreakpointCommandsCB   (Widget, XtPointer, XtPointer);
+    static void SetBreakpointIgnoreCountNowCB(XtPointer, XtIntervalId *);
+    static void DeleteInfoCB               (Widget, XtPointer, XtPointer);
+    static void RefreshBreakpointsHP       (Agent *, void *, void *);
+    static void RecordingHP                (Agent *, void *, void *);
 
     static void UpdateBreakpointButtonsCB (Widget, XtPointer, XtPointer);
 
     static void CheckScrollCB(Widget, XtPointer, XtPointer);
     static void CheckScrollWorkProc(XtPointer, XtIntervalId *);
 
-    static void InhibitModificationCB      (Widget, XtPointer, XtPointer);
+    static void CheckModificationCB        (Widget, XtPointer, XtPointer);
 
     static void StackDialogPoppedDownCB    (Widget, XtPointer, XtPointer);
     static void CodeDialogPoppedDownCB     (Widget, XtPointer, XtPointer);
@@ -132,13 +148,17 @@ class SourceView {
     static void SelectFrameCB    (Widget, XtPointer, XtPointer);
     static void SelectRegisterCB (Widget, XtPointer, XtPointer);
     static void SelectThreadCB   (Widget, XtPointer, XtPointer);
+    static void ThreadCommandCB  (Widget, XtPointer, XtPointer);
+
+    static void SetWatchModeCB(Widget, XtPointer, XtPointer);
 
     static void update_title ();
-    static void MoveCursorToGlyphPosCB(Widget, XtPointer, XtPointer);
+    static void ActivateGlyphCB(Widget, XtPointer, XtPointer);
     static int line_height (Widget text_w);
 
     static void create_text(Widget parent,
-			    const string& base, Widget& form, Widget& text);
+			    const string& base, bool editable,
+			    Widget& form, Widget& text);
 
     static void refresh_bp_disp ();
     static void refresh_source_bp_disp ();
@@ -147,11 +167,47 @@ class SourceView {
     static void clearBP(void *client_data, XtIntervalId *timer);
     static void clearJumpBP(const string& answer, void *client_data);
 
-    // Move breakpoint NR to ADDRESS
-    static void move_bp(int nr, const string& address, Widget origin = 0);
+    // Move/Copy breakpoint NR to ADDRESS; return true if changed
+    static bool move_bp(int nr, const string& address, Widget origin = 0,
+			bool copy = false);
+    static bool copy_bp(int nr, const string& address, Widget origin = 0)
+    {
+	return move_bp(nr, address, origin, true);
+    }
 
-    // Set condition of breakpoint NR to COND
-    static void set_bp_cond(int nr, const string& cond, Widget origin = 0);
+    // Set condition of breakpoints NRS to COND.
+    // * If COND is char(-1), preserve old condition.
+    // * If MAKE_FALSE is >= 0, disable breakpoint by making 
+    //   the condition false.
+    // * If MAKE_FALSE is == 0, enable breakpoint by restoring
+    //   the original condition.
+    // * Otherwise, preserve the condition state.
+    static void _set_bps_cond(IntArray& nrs, string cond, 
+			      int make_false, Widget origin);
+
+    // Set condition of breakpoints NRS to COND.
+    inline static void set_bps_cond(IntArray& nrs, string cond,
+				    Widget origin = 0)
+    {
+	_set_bps_cond(nrs, cond, -1, origin);
+    }
+
+    // Enable and disable breakpoints via conditions.
+    inline static void set_bps_cond_enabled(IntArray& nrs, bool enabled,
+					    Widget origin = 0)
+    {
+	_set_bps_cond(nrs, char(-1), enabled ? 0 : 1, origin);
+    }
+
+    // Custom calls
+    inline static void enable_bps_cond(IntArray& nrs, Widget origin = 0)
+    {
+	set_bps_cond_enabled(nrs, true, origin);
+    }
+    inline static void disable_bps_cond(IntArray& nrs, Widget origin = 0)
+    {
+	set_bps_cond_enabled(nrs, false, origin);
+    }
 
     // Find the line number at POS.  LINE_NR becomes the line number
     // at POS.  IN_TEXT becomes true iff POS is in the source area.
@@ -181,6 +237,8 @@ class SourceView {
     static void dragGlyphAct      (Widget, XEvent*, String*, Cardinal*);
     static void followGlyphAct    (Widget, XEvent*, String*, Cardinal*);
     static void dropGlyphAct      (Widget, XEvent*, String*, Cardinal*);
+    static void deleteGlyphAct    (Widget, XEvent*, String*, Cardinal*);
+    static void doubleClickAct    (Widget, XEvent*, String*, Cardinal*);
 
     //-----------------------------------------------------------------------
     // Timer procedures
@@ -213,12 +271,6 @@ class SourceView {
     static bool code_history_locked;
     static bool checking_scroll;
 
-    static XmTextPosition last_start_secondary_highlight;
-    static XmTextPosition last_end_secondary_highlight;
-
-    static XmTextPosition last_start_secondary_highlight_pc;
-    static XmTextPosition last_end_secondary_highlight_pc;
-
     static Widget toplevel_w;	 // Top-level widget
 
     static Widget source_form_w; // Form around text and glyphs
@@ -253,6 +305,8 @@ class SourceView {
     static bool at_lowest_frame;              // Are we at lowest frame?
     static bool signal_received;	      // Did we receive a signal?
 
+    static WatchMode selected_watch_mode;     // Last selected watch mode
+
     // Tab width
     static int tab_width;
 
@@ -267,11 +321,21 @@ class SourceView {
     static StringArray bp_addresses;
     static XmTextPosition pos_of_line(int line);
 
-    // Return TRUE if breakpoint BP is in current file
-    static bool bp_matches(BreakPoint *bp);
+    // True iff breakpoint BP is in current file (at LINE, if given)
+    static bool bp_matches(BreakPoint *bp, int line = 0);
+
+    // True iff breakpoint BP is in FILE (at LINE, if given)
+    static bool bp_matches(BreakPoint *bp, const string& file, int line = 0);
+
+    // True iff FILE1 is equal to FILE2
     static bool file_matches(const string& file1, const string& file2);
+
+    // True iff the base names of FILE1 and FILE2 are equal
     static bool base_matches(const string& file1, const string& file2);
 
+    // True iff FILE is the currently loaded file
+    static bool is_current_file(const string& file);
+
     static StringStringAssoc file_cache;
     static StringOriginAssoc origin_cache;
     static CodeCache code_cache;
@@ -294,9 +358,28 @@ class SourceView {
     static StringStringAssoc source_name_cache;
     static string current_source_name();
 
+    // File name of current source (for JDB)
+    static StringStringAssoc file_name_cache;
+
+    // Files listed as erroneous
+    static StringArray bad_files;
+    static bool new_bad_file(const string& file_name);
+    static void post_file_error(const string& file_name,
+				string text, String name = 0,
+				Widget origin = 0);
+    static void post_file_warning(const string& file_name,
+				  string text, String name = 0,
+				  Widget origin = 0);
+
     // The current directory
     static string current_pwd;
 
+    // The current JDB search path
+    static string current_class_path;
+
+    // The current JDB threadgroup.
+    static string current_threadgroup;
+
     // Some positions in source text.
     static XmTextPosition last_top;
     static XmTextPosition last_pos;
@@ -324,7 +407,10 @@ class SourceView {
 			     bool silent);
     static String read_remote(const string& file_name, long& length,
 			      bool silent);
-    static String read_from_gdb(const string& file_name, long& length,
+    static String read_class(const string& class_name, 
+			     string& file_name, SourceOrigin& origin,
+			     long& length, bool silent);
+    static String read_from_gdb(const string& source_name, long& length,
 				bool silent);
 
     static String read_indented(string& file_name, long& length,
@@ -346,8 +432,9 @@ class SourceView {
     static bool is_code_widget(Widget w);
     static string& current_text(Widget w);
 
-    // Return current breakpoint indent amount
-    static int indent_amount(Widget w);
+    // Return current breakpoint indent amount.  If POS is given, add
+    // the whitespace from POS.
+    static int indent_amount(Widget w, int pos = -1);
 
     // Format `where' and `thread' lines
     static void setup_where_line(string& line);
@@ -374,13 +461,22 @@ class SourceView {
     // Check if function at PC is larger than MAX_SIZE
     static bool function_is_larger_than(string pc, int max_size);
 
+    // Breakpoint properties.
+    static void update_properties_panel(BreakpointPropertiesInfo *info);
+    static void update_properties_panels();
+    static void move_breakpoint_properties(int old_bp, int new_bp);
+    static void copy_breakpoint_properties(int old_bp, int new_bp);
+
     //-----------------------------------------------------------------------
     // Glyphs
     //-----------------------------------------------------------------------
 
+    // Create a pixmap from BITS suitable for the widget W
+    static Pixmap pixmap(Widget w, unsigned char *bits, int width, int height);
+
     // Create glyph in FORM_W named NAME from given BITS
     static Widget create_glyph(Widget form_w, String name, 
-			       char *bits, int width, int height);
+			       unsigned char *bits, int width, int height);
 
     // Map glyph W in (X, Y)
     static void map_glyph(Widget& w, Position x, Position y);
@@ -388,10 +484,17 @@ class SourceView {
     // Unmap glyph W
     static void unmap_glyph(Widget w);
 
+    // Report glyph state (for debugging)
+    static void log_glyph(Widget w, int n = -1);
+    static void log_glyphs();
+
     // Return position during glyph drag and drop
     static XmTextPosition glyph_position(Widget w, XEvent *e, 
 					 bool normalize = true);
 
+    // Get relative coordinates of GLYPH in TEXT
+    static void translate_glyph_pos(Widget glyph, Widget text, int& x, int& y);
+
     // Data associated with current drag operation
     // The Glyph being dragged
     static Widget current_drag_origin;
@@ -410,37 +513,48 @@ public:
     static int multiple_stop_x_offset;
 
 private:
-    // Glyph locations: x[0] is source, x[1] is code
+    // Glyph locations: X[0] is source, X[1] is code
     static Widget plain_arrows[2];
     static Widget grey_arrows[2];
     static Widget signal_arrows[2];
-    static Widget temp_arrows[2];
-    static Widget plain_stops[2][MAX_GLYPHS + 1];
-    static Widget grey_stops[2][MAX_GLYPHS + 1];
-    static Widget temp_stops[2];
+    static Widget drag_arrows[2];
+    static WidgetArray plain_stops[2];
+    static WidgetArray grey_stops[2];
+    static WidgetArray plain_conds[2];
+    static WidgetArray grey_conds[2];
+    static WidgetArray plain_temps[2];
+    static WidgetArray grey_temps[2];
+    static Widget drag_stops[2];
+    static Widget drag_conds[2];
+    static Widget drag_temps[2];
 
     // Map stop sign in W at position POS.  Get widget from STOPS[COUNT];
     // store location in POSITIONS.  Return mapped widget (0 if none)
     static Widget map_stop_at(Widget w, XmTextPosition pos,
-			      Widget stops[], int& count,
+			      WidgetArray& stops, int& count,
 			      TextPositionArray& positions);
 
-    // Map arrow/temp arrow/temp stop in W at POS.  If ORIGIN is
+    // Map arrow/drag arrow/drag stop in W at POS.  If ORIGIN is
     // given, use colors from ORIGIN.
     static Widget map_arrow_at     (Widget w, XmTextPosition pos);
-    static Widget map_temp_arrow_at(Widget w, XmTextPosition pos,
+    static Widget map_drag_arrow_at(Widget w, XmTextPosition pos,
 				    Widget origin = 0);
-    static Widget map_temp_stop_at (Widget w, XmTextPosition pos,
+    static inline void unmap_drag_arrow(Widget w)
+    {
+	map_drag_arrow_at(w, XmTextPosition(-1));
+    }
+    static Widget map_drag_stop_at (Widget w, XmTextPosition pos,
 				    Widget origin = 0);
+    static inline void unmap_drag_stop(Widget w)
+    {
+	map_drag_stop_at(w, XmTextPosition(-1));
+    }
     static void copy_colors(Widget w, Widget origin);
 
     // True if code/source glyphs need to be updated
     static bool update_code_glyphs;
     static bool update_source_glyphs;
 
-    // Update glyphs for widget W (0: all)
-    static void update_glyphs(Widget w = 0);
-
     // Helping background procedures
     static void UpdateGlyphsWorkProc(XtPointer, XtIntervalId *);
     static Boolean CreateGlyphsWorkProc(XtPointer);
@@ -460,11 +574,15 @@ private:
 
     static int max_breakpoint_number_seen;
 
+    // Return breakpoint number of BP_INFO; 0 if new; -1 if none
+    static int jdb_breakpoint(const string& bp_info);
+
 public:
     // Constructor
-    SourceView (XtAppContext app_context, Widget parent);
+    SourceView(Widget parent);
 
-    enum SearchDirection {forward, backward};
+    // Shell constructor
+    void create_shells();
 
     // Set current execution position, based on the GDB position info
     // POSITION; no arg means clear current position.
@@ -518,6 +636,9 @@ public:
     // Handle 'pwd' information
     static void process_pwd             (string& pwd_output);
 
+    // Handle 'use' information
+    static void process_use             (string& use_output);
+
     // Process the remainder of an output line
     static void check_remainder         (string& info_output);
 
@@ -528,6 +649,8 @@ public:
     static bool set_frame_func(const string& func);
 
     // Find S in current source; select it at TIME.
+    enum SearchDirection {forward, backward};
+
     static void find(const string& s,
 		     SearchDirection direction = forward,
 		     bool words_only = false,
@@ -535,7 +658,7 @@ public:
 		     Time time = CurrentTime);
 
     // Locate function S; if S is omitted, locate last execution position.
-    static void lookup(string s = "", bool silent = false);
+    static void lookup(string s, bool silent = false);
 
     // Read file FILE_NAME; place cursor at INITIAL_LINE.
     static void read_file(string file_name,
@@ -565,7 +688,7 @@ public:
     // Refreshing dialogs
     static void refresh_stack_frames();
     static void refresh_registers();
-    static void refresh_threads();
+    static void refresh_threads(bool all_threadgroups);
 
     // Refreshing commands
     static string refresh_registers_command();
@@ -594,6 +717,15 @@ public:
     // Set the tab width
     static void set_tab_width(int width);
 
+    // Set the indentation
+    static void set_indent(int source_indent, int code_indent);
+
+    // Set the max number of glyphs
+    static void set_max_glyphs(int max_glyphs);
+
+    // Whether to cache glyph images
+    static bool cache_glyph_images;
+
     // Maximum length of expr in source popup
     static int max_popup_expr_length;
 
@@ -627,18 +759,65 @@ public:
     // Create a temporary breakpoint at A and continue execution.
     static void temp_n_cont(const string& a, Widget origin = 0);
 
-    // Enable or disable breakpoint NR
-    static void enable_bp(int nr,  Widget origin = 0);
-    static void disable_bp(int nr, Widget origin = 0);
+    // Enable/Disable/Delete/Edit breakpoints
+    static void enable_bps     (IntArray& nrs, Widget origin = 0);
+    static void disable_bps    (IntArray& nrs, Widget origin = 0);
+    static void delete_bps     (IntArray& nrs, Widget origin = 0);
+    static void edit_bps       (IntArray& nrs, Widget origin = 0);
 
-    // Move PC to ADDRESS
-    static void move_pc(const string& address, Widget origin = 0);
+    inline static void enable_bp(int nr, Widget origin = 0)
+    {
+	IntArray nrs;
+	nrs += nr;
+	enable_bps(nrs, origin);
+    }
+
+    inline static void disable_bp(int nr, Widget origin = 0)
+    {
+	IntArray nrs;
+	nrs += nr;
+	disable_bps(nrs, origin);
+    }
+
+    inline static void delete_bp(int nr, Widget origin = 0)
+    {
+	IntArray nrs;
+	nrs += nr;
+	delete_bps(nrs, origin);
+    }
+
+    inline static void edit_bp(int nr, Widget origin = 0)
+    {
+	IntArray nrs;
+	nrs += nr;
+	edit_bps(nrs, origin);
+    }
+
+    // Set breakpoint commands
+    static void set_bp_commands(IntArray& nrs, const StringArray& commands,
+				Widget origin = 0);
+    inline static void set_bp_commands(int nr, const StringArray& commands,
+				       Widget origin = 0)
+    {
+	IntArray nrs;
+	nrs += nr;
+	set_bp_commands(nrs, commands, origin);
+    }
+
+    static string numbers(const IntArray& nrs);
+    static string all_numbers(const IntArray& nrs);
+    static bool all_bps(const IntArray& nrs);
+	    
+    // Move PC to ADDRESS; return true if changed.
+    static bool move_pc(const string& address, Widget origin = 0);
 
     // Return `clear ARG' command.  If CLEAR_NEXT is set, attempt to
     // guess the next event number and clear this one as well.
     // Consider only breakpoints whose number is >= FIRST_BP.
     static string clear_command(string arg, bool clear_next = false,
 				int first_bp = 0);
+    // Return `delete N' command.
+    static string delete_command(int bp_nr);
 
     // Return `{ COMMAND; }'
     static string command_list(string cmd);
@@ -646,6 +825,9 @@ public:
     // Return current directory
     static string pwd() { return current_pwd; }
 
+    // Return current class path
+    static string class_path() { return current_class_path; }
+
     // Return source text and machine code widget (read-only)
     static Widget source() { return source_text_w; }
     static Widget code()   { return code_text_w; }
@@ -671,7 +853,10 @@ public:
     static string bp_pos(int num);
 
     // Return the breakpoint at POS (0 if none)
-    static BreakPoint *bp_at(string pos);
+    static BreakPoint *breakpoint_at(string pos);
+
+    // Return the watchpoint at EXPR (0 if none)
+    static BreakPoint *watchpoint_at(string expr);
 
     // Get the word at position of EVENT
     static string get_word_at_event(Widget w,
@@ -699,6 +884,9 @@ public:
     // True iff we have some selection
     static bool have_selection();
 
+    // True iff we need the current program counter
+    static bool need_pc() { return disassemble; }
+
     // Return current frame (-1 if unknown)
     static int get_frame() { return current_frame; }
 
@@ -711,6 +899,12 @@ public:
     // Helpers
     static string full_path(string file);
     static const char *basename(const char *);
+
+    // Edit breakpoint properties.
+    static void edit_breakpoint_properties(int bp_nr);
+
+    // Update glyphs for widget W (0: all)
+    static void update_glyphs(Widget w = 0);
 };
 
 inline void SourceView::create_bp(const string& a, Widget w)
