@@ -1,23 +1,23 @@
-// $Id: TTYAgent.h,v 1.18 1997/12/15 13:00:08 zeller Exp $ -*- C++ -*-
+// $Id: TTYAgent.h,v 1.20 1998/04/02 09:05:37 zeller Exp $ -*- C++ -*-
 // An agent interface using ptys (pseudo ttys)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -63,7 +63,10 @@ protected:
     // Open a tty.
     // Like open(TTY, FLAGS), but care for EAGAIN and EWOULDBLOCK conditions
     virtual int open_tty(const char *tty, int flags = O_RDWR);
-    
+
+    // Check whether a TTY is usable
+    virtual bool tty_ok(const char *tty);
+
 public:
     // Constructors
     TTYAgent(XtAppContext app_context, string pth,
