@@ -1,23 +1,23 @@
-// $Id: VSLDef.h,v 1.10 1997/12/15 18:54:15 zeller Exp $
+// $Id: VSLDef.h,v 1.12 1998/05/11 08:40:08 zeller Exp $
 // Deklaration Klasse VSLDef
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -71,38 +71,16 @@ private:
 public:
     VSLDefList *deflist;        // Vater
 
-    // Erzeugen
+    // Constructor
     VSLDef(VSLDefList* l, VSLNode *pattern, VSLNode *e = 0,
-	string filename = "builtin", int lineno = 0)
-	: _expr(e),
-	_node_pattern(pattern),
-	_box_pattern(0),
-	_nargs(pattern->nargs()),
-	_straight(pattern->isStraight()),
-	_filename(filename),
-	_lineno(lineno),
-	_listnext(0), _libnext(0), _libprev(0),
-	being_compiled(false),
-	deflist(l)
-    {}
+	string filename = "builtin", int lineno = 0);
 
 private:
-    VSLDef(const VSLDef&)
-	:_expr(0),
-	_node_pattern(0),
-	_box_pattern(0),
-	_nargs(0),
-	_straight(0),
-	_filename(),
-	_lineno(0),
-	_listnext(0), _libnext(0), _libprev(0),
-	being_compiled(false),
-	deflist(0)
-    {
-	assert(0);
-    }
+    // `Dummy' copy constructor
+    VSLDef(const VSLDef&);
 
-    VSLDef& operator = (const VSLDef&) { assert(0); return *this; }
+    // `Dummy' assignment
+    VSLDef& operator = (const VSLDef&);
 
 public:
     // Ressourcen
@@ -110,7 +88,7 @@ public:
     VSLNode*& node_pattern()    { return _node_pattern; }
     Box*& box_pattern()         { return _box_pattern; }
     unsigned nargs() const      { return _nargs; }
-    bool straight() const    { return _straight; }
+    bool straight() const       { return _straight; }
 
     VSLDef*& listnext()         { return _listnext; }
     VSLDef*& libnext()          { return _libnext; }
