@@ -1,7 +1,7 @@
-// $Id: acconfig.h.in,v 1.29 1998/01/28 14:17:56 zeller Exp $ -*- C++ -*-
+// $Id: acconfig.h.in,v 1.33 1998/06/04 17:31:45 zeller Exp $ -*- C++ -*-
 // General configuration file.
 
-// Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
+// Copyright (C) 1995-1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
 // This file is part of the ICE Library.
@@ -21,8 +21,10 @@
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// ICE is the incremental configuration engine.
-// Contact ice@ips.cs.tu-bs.de for details.
+// ICE is the incremental configuration environment.
+// For details, see the ICE World-Wide-Web page, 
+// http://www.cs.tu-bs.de/softech/ice/,
+// or send a mail to the ICE developers <ice@ips.cs.tu-bs.de>.
 
 #ifndef _ICE_config_h
 #define _ICE_config_h
@@ -32,6 +34,9 @@
 // Leave the following blank line there!!  Autoheader needs it.
 
 
+/* The package name. */
+#undef PACKAGE
+
 /* Define if your C++ compiler has ANSI-compliant lifetime of temporaries. */
 #undef HAVE_ANSI_LIFETIME_OF_TEMPORARIES
 
@@ -84,6 +89,9 @@
 /* Define if your Motif widgets are actually LessTif widgets. */
 #undef HAVE_LESSTIF
 
+/* Define if the Motif library defines xmUseVersion */
+#undef HAVE_XMUSEVERSION
+
 /* Define if your C++ compiler supports named return values. */
 #undef HAVE_NAMED_RETURN_VALUES
 
@@ -132,9 +140,19 @@
    too.  Requires WITH_RUNTIME_REGEX to be set.  Required in ICE.  */
 #undef RUNTIME_REGEX
 
+/* Define if you want the manual to be compiled into the executable. */
+#undef WITH_BUILTIN_MANUAL
+
+/* Define if you want the app-defaults file to be compiled into the
+   executable. */
+#undef WITH_BUILTIN_APP_DEFAULTS
+
 
 // @BOTTOM@
 
+/* Define if alloca is declared in alloca.h stdlib.h. */
+#undef HAVE_ALLOCA_DECL
+
 /* Define if asctime is declared in time.h. */
 #undef HAVE_ASCTIME_DECL
 
@@ -312,9 +330,6 @@
 /* Define if unlockpt is declared in stdlib.h. */
 #undef HAVE_UNLOCKPT_DECL
 
-/* Define if vfork is declared in vfork.h unistd.h. */
-#undef HAVE_VFORK_DECL
-
 /* Define if waitpid is declared in sys/wait.h. */
 #undef HAVE_WAITPID_DECL
 
