@@ -1,3 +1,4 @@
+ICE_CHECK_DECL(alloca, alloca.h stdlib.h)
 ICE_CHECK_DECL(asctime, time.h)
 ICE_CHECK_DECL(difftime, time.h)
 ICE_CHECK_DECL(dup2, unistd.h)
@@ -57,5 +58,4 @@ ICE_CHECK_DECL(times, sys/times.h)
 ICE_CHECK_DECL(uname, sys/utsname.h)
 ICE_CHECK_DECL(unlink, unistd.h)
 ICE_CHECK_DECL(unlockpt, stdlib.h)
-ICE_CHECK_DECL(vfork, vfork.h unistd.h)
 ICE_CHECK_DECL(waitpid, sys/wait.h)
