@@ -1,23 +1,23 @@
-// $Id: args.h,v 1.6 1997/11/15 23:48:53 zeller Exp $ -*- C++ -*-
+// $Id: args.h,v 1.8 1998/03/25 12:45:17 zeller Exp $ -*- C++ -*-
 // Argument Dialog
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -46,5 +46,7 @@ void gdbChangeDirectoryCB(Widget w, XtPointer, XtPointer);
 void add_to_arguments(string line);
 void update_arguments();
 
+void add_running_arguments(string& cmd);
+
 #endif // _DDD_args_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
