@@ -1,23 +1,23 @@
-// $Id: buttons.h,v 1.12 1998/01/12 17:05:51 zeller Exp $ -*- C++ -*-
+// $Id: buttons.h,v 1.15 1998/05/18 15:16:14 zeller Exp $ -*- C++ -*-
 // DDD buttons
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -63,5 +63,11 @@ void refresh_button_editor();
 // Get a value from GDB
 string gdbValue(const string& expr);
 
+// Create a flat PushButton named NAME
+Widget create_flat_button(Widget parent, const string& name);
+
+// Remove command from help cache.
+void clear_help_cache(const string& command);
+
 #endif // _DDD_buttons_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
