@@ -1,23 +1,23 @@
-// $Id: charsets.h,v 1.5 1997/10/03 10:40:00 zeller Exp $ -*- C++ -*-
+// $Id: charsets.h,v 1.8 1998/05/06 18:41:16 zeller Exp $ -*- C++ -*-
 // Character sets used in DDD
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -37,12 +37,21 @@
 
 // Character sets
 
+// The default charset (for button labels, etc.)
+#define CHARSET_DEFAULT  MSTRING_DEFAULT_CHARSET
+
 // The fixed-width font used in texts.
 #define CHARSET_TT "tt"
 
 // The bold variant of TT.
 #define CHARSET_TB "tb"
 
+// The slanted variant of TT.
+#define CHARSET_TS "ts"
+
+// The bold slanted variant of TT.
+#define CHARSET_TBS "tbs"
+
 // Roman text.
 #define CHARSET_RM "rm"
 
@@ -55,6 +64,27 @@
 // Bold slanted text
 #define CHARSET_BS "bs"
 
+// Key caps
+#define CHARSET_KEY "key"
+
+// The fixed-width font used in text fields
+#define CHARSET_TEXT "text"
+
+// Logo
+#define CHARSET_LOGO "logo"
+
+// Large logo
+#define CHARSET_LLOGO "llogo"
+
+// Symbol
+#define CHARSET_SYMBOL "symbol"
+
+// Small font (for `<<' and `>>')
+#define CHARSET_SMALL "small"
+
+// Light font (for the command tool buttons)
+#define CHARSET_LIGHT "light"
+
 
 // Convenience functions
 inline MString tt(const string& text) { return MString(text, CHARSET_TT); }
