@@ -1,4 +1,4 @@
-/* $Id: ctest.c,v 1.7 1997/10/03 10:40:15 zeller Exp $ */
+/* $Id: ctest.c,v 1.8 1998/03/05 14:46:36 zeller Exp $ */
 /* C Test program */
 
 /*
@@ -35,13 +35,15 @@
  */
 
 char ctest_rcsid[] =
-    "$Id: ctest.c,v 1.7 1997/10/03 10:40:15 zeller Exp $";
+    "$Id: ctest.c,v 1.8 1998/03/05 14:46:36 zeller Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
 
 typedef enum _DayOfWeek {Sun, Mon, Tue, Wed, Thu, Fri, Sat} DayOfWeek;
 
+int a_global = 42;	/* Place watchpoints on this one */
+
 typedef struct Date {
     DayOfWeek day_of_week;
     int day;
@@ -90,6 +92,7 @@ void set_holiday(d, day_of_week, day, month, year, name)
 {
     set_date(&d->date, day_of_week, day, month, year);
     d->name = name;
+    a_global = 1;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -126,6 +129,25 @@ void free_tree(tree)
     free(tree);
 }
 
+/*--------------------------------------------------------------------------*/
+typedef struct _List {
+    int value;
+
+    struct _List *self;
+    struct _List *next;
+} List;
+
+List *new_list(value)
+    int value;
+{
+    List *list = (List *)malloc(sizeof(List));
+    list->value = value;
+    list->self  = list;
+    list->next  = list;
+
+    return list;
+}
+
 /*--------------------------------------------------------------------------*/
 void tree_test ()
 {
@@ -142,6 +164,22 @@ void tree_test ()
     free_tree(tree);
 }
 
+/*--------------------------------------------------------------------------*/
+void list_test(start)
+    int start;
+{
+    List *list = 0;
+
+    list                         = new_list(a_global + start++);
+    list->next                   = new_list(a_global + start++);
+    list->next->next             = new_list(a_global + start++);
+    list->next->next->next       = list;
+
+    free(list->next->next);
+    free(list->next);
+    free(list);
+}
+
 /*--------------------------------------------------------------------------*/
 void array_test ()
 {
@@ -208,6 +246,8 @@ int main (argc, argv)
     int i = 42;
     tree_test();
     i++;
+    list_test(i);
+    i++;
     array_test();
     i++;
     type_test();
