@@ -28,6 +28,7 @@
 "\n"
 "\n"
 "\n"
+"\n"
 "#line 1 \"../vsllib/std.vsl\"\n"
 "\n"
 "\n"
@@ -373,7 +374,7 @@
 "dquote() = \"\\\"\";\n"
 "squote() = \"'\";\n"
 "copyright() = \"(c)\";\n"
-"#line 30 \"ddd.vsl\"\n"
+"#line 31 \"ddd.vsl\"\n"
 "\n"
 "#line 1 \"../vsllib/tab.vsl\"\n"
 "\n"
@@ -753,7 +754,7 @@
 "\n"
 "\n"
 "\n"
-"tab_version() = \"$Id: tab.vsl,v 1.7 1997/11/15 21:27:22 zeller Exp $\";\n"
+"tab_version() = \"$Id: tab.vsl,v 1.8 1998/03/25 14:21:56 zeller Exp $\";\n"
 "\n"
 "\n"
 "\n"
@@ -763,6 +764,12 @@
 "\n"
 "\n"
 "\n"
+"\n"
+"\n"
+"\n"
+"\n"
+"\n"
+"tab_elem([]) = tab_elem(0);\n"
 "tab_elem(x) = whiteframe(x);\n"
 "\n"
 "\n"
@@ -780,11 +787,13 @@
 "_tab_heads([]) = [];\n"
 "_tab_heads([[head : _] : more]) =\n"
 "[tab_elem(head) : _tab_heads(more)];\n"
+"_tab_heads([x]) = [tab_elem(x)];\n"
 "\n"
 "\n"
 "_tab_tails([]) = [];\n"
 "_tab_tails([[_ : tail] : more]) =\n"
 "[tail : _tab_tails(more)];\n"
+"_tab_tails(_) = [];\n"
 "\n"
 "\n"
 "_tab_width(...) =\n"
@@ -798,12 +807,20 @@
 "width | tab_elem(head);\n"
 "_tab_line([width : twidth], [head : tail]) =\n"
 "_tab_line([width], [head]) & _tab_line(twidth, tail);\n"
+"_tab_line([width], x) =\n"
+"_tab_line([width], [x]);\n"
+"_tab_line([width : twidth], x) =\n"
+"_tab_line([width], [x]) & _tab_line(twidth, 0);\n"
 "\n"
 "\n"
 "_dtab_line([width], [head]) =\n"
 "width | tab_elem(head);\n"
 "_dtab_line([width : twidth], [head : tail]) =\n"
 "_dtab_line([width], [head]) & vrule() & _dtab_line(twidth, tail);\n"
+"_dtab_line([width], x) =\n"
+"_tab_line([width], [x]);\n"
+"_dtab_line([width : twidth], x) =\n"
+"_tab_line([width], [x]) & vwhite(rulethickness()) & _dtab_line(twidth, 0);\n"
 "\n"
 "\n"
 "_tab(width, [head]) =\n"
@@ -832,7 +849,7 @@
 "hrule()\n"
 "| _dtab(_tab_width(...), ...)\n"
 "| hrule();\n"
-"#line 31 \"ddd.vsl\"\n"
+"#line 32 \"ddd.vsl\"\n"
 "\n"
 "#line 1 \"../vsllib/fonts.vsl\"\n"
 "\n"
@@ -864,7 +881,7 @@
 "\n"
 "\n"
 "\n"
-"fonts_version() = \"$Id: fonts.vsl,v 1.9 1997/10/08 13:19:53 zeller Exp $\";\n"
+"fonts_version() = \"$Id: fonts.vsl,v 1.10 1998/04/24 09:38:02 zeller Exp $\";\n"
 "\n"
 "\n"
 "_font(box, font) = font(box, font);\n"
@@ -887,8 +904,8 @@
 "\n"
 "\n"
 "stdfontfamily() = family_times();\n"
-"stdfontsize() = 12;\n"
-"stdfontpoints() = 0;\n"
+"stdfontsize() = 0;\n"
+"stdfontpoints() = 90;\n"
 "stdfontslant() = slant_unslanted();\n"
 "stdfontweight() = weight_medium();\n"
 "\n"
@@ -993,7 +1010,7 @@
 "\n"
 "sl(...) = it(...);\n"
 "bs(...) = bi(...);\n"
-"#line 32 \"ddd.vsl\"\n"
+"#line 33 \"ddd.vsl\"\n"
 "\n"
 "#line 1 \"../vsllib/colors.vsl\"\n"
 "\n"
@@ -1030,7 +1047,7 @@
 "\n"
 "color(box, fg, bg)   = foreground(background(box, bg), fg);\n"
 "color(box, fg)       = foreground(box, fg);\n"
-"#line 33 \"ddd.vsl\"\n"
+"#line 34 \"ddd.vsl\"\n"
 "\n"
 "\n"
 "\n"
@@ -1101,11 +1118,11 @@
 "\n"
 "\n"
 "collapsed_array () ->\n"
-"array_color(vcenter(rm(\"[...]\") & hfill()));\n"
+"array_color(vcenter(rm(\"\\133...\\135\") & hfill()));\n"
 "\n"
 "\n"
 "empty_array () ->\n"
-"array_color(vcenter(rm(\"[]\") & hfill()));\n"
+"array_color(vcenter(rm(\"\\133\\135\") & hfill()));\n"
 "\n"
 "\n"
 "vertical_array (...) ->\n"
@@ -1176,5 +1193,9 @@
 "changed_color(it(value));\n"
 "\n"
 "\n"
+"repeated_value (value, n) ->\n"
+"value & vcenter(rm(\" <\" & dec(n) & \"\\327>\"));\n"
+"\n"
+"\n"
 "display_box (title, value) ->\n"
 "shadow(display_color(frame(title | hrule() | hwhite () | rm(value))));\n"
