@@ -1,23 +1,23 @@
-// $Id: editing.h,v 1.11 1997/10/27 22:03:04 zeller Exp $ -*- C++ -*-
+// $Id: editing.h,v 1.14 1998/06/10 17:38:04 zeller Exp $ -*- C++ -*-
 // DDD command-line actions and callbacks
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -39,6 +39,7 @@
 
 // Actions
 extern void controlAct            (Widget, XEvent*, String*, Cardinal*);
+extern void interruptAct          (Widget, XEvent*, String*, Cardinal*);
 extern void commandAct            (Widget, XEvent*, String*, Cardinal*);
 extern void processAct            (Widget, XEvent*, String*, Cardinal*);
 extern void forward_characterAct  (Widget, XEvent*, String*, Cardinal*);
@@ -77,6 +78,9 @@ extern void gdbClearWindowCB     (Widget, XtPointer, XtPointer);
 // Return current GDB command line.
 extern string current_line();
 
+// Set current GDB input line
+extern void set_current_line(const string& input);
+
 // True if last input was at GDB prompt.
 extern bool gdb_input_at_prompt;
 
@@ -84,8 +88,11 @@ extern bool gdb_input_at_prompt;
 // RESET means to reset the history; SHOW means to redisplay.
 extern void clear_isearch(bool reset = false, bool show = true);
 
-// Pass the COMMAND given in CLIENT_DATA to gdb_command()
+// Pass the COMMAND given in CLIENT_DATA to gdb_button_command()
 void gdbCommandCB(Widget w, XtPointer client_data, XtPointer call_data);
 
+// Like gdb_command(), but perform `...' and `()' substitutions
+void gdb_button_command(const string& command, Widget origin = 0);
+
 #endif // _DDD_editing_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
