@@ -1,23 +1,23 @@
-// $Id: exit.h,v 1.12 1997/12/15 18:41:57 zeller Exp $ -*- C++ -*-
+// $Id: exit.h,v 1.15 1998/06/09 07:36:03 zeller Exp $ -*- C++ -*-
 // Exit DDD
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -53,8 +53,12 @@ void DDDExitCB    (Widget, XtPointer, XtPointer); // Exit DDD
 void DDDRestartCB (Widget, XtPointer, XtPointer); // Restart DDD
 
 // Helpers
-void gdb_eofHP  (class Agent *, void *, void *);
-void gdb_diedHP (class Agent *, void *, void *);
+class Agent;
+void gdb_eofHP  (Agent *, void *, void *);
+void gdb_diedHP (Agent *, void *, void *);
+
+// True if GDB is about to exit
+extern bool gdb_is_exiting;
 
 // True if DDD is about to exit
 extern bool ddd_is_exiting;
