@@ -1,23 +1,23 @@
-// $Id: file.h,v 1.9 1997/10/03 10:40:38 zeller Exp $ -*- C++ -*-
+// $Id: file.h,v 1.14 1998/06/14 11:40:05 zeller Exp $ -*- C++ -*-
 // DDD file handling
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -35,12 +35,22 @@
 
 #include <X11/Intrinsic.h>
 #include "strclass.h"
+#include "StringA.h"
 
 // Open file, process, core, source ...
-extern void gdbOpenFileCB   (Widget, XtPointer, XtPointer);
-extern void gdbOpenProcessCB(Widget, XtPointer, XtPointer);
-extern void gdbOpenCoreCB   (Widget, XtPointer, XtPointer);
-extern void gdbOpenSourceCB (Widget, XtPointer, XtPointer);
+extern void gdbOpenFileCB     (Widget, XtPointer, XtPointer);
+extern void gdbOpenRecentCB   (Widget, XtPointer, XtPointer);
+extern void gdbOpenClassCB    (Widget, XtPointer, XtPointer);
+extern void gdbOpenProcessCB  (Widget, XtPointer, XtPointer);
+extern void gdbOpenCoreCB     (Widget, XtPointer, XtPointer);
+extern void gdbOpenSourceCB   (Widget, XtPointer, XtPointer);
+extern void gdbLookupSourceCB (Widget, XtPointer, XtPointer);
+
+// Get all sources from GDB
+void get_gdb_sources(StringArray& sources_list);
+
+// Update sources list
+void update_sources();
 
 // When entering `cd', change path in file selection boxes
 extern void process_cd(string pwd);
