@@ -1,23 +1,23 @@
-// $Id: history.h,v 1.8 1997/10/03 10:40:52 zeller Exp $ -*- C++ -*-
+// $Id: history.h,v 1.13 1998/06/09 07:36:05 zeller Exp $ -*- C++ -*-
 // DDD command history
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -35,6 +35,8 @@
 
 #include "strclass.h"
 #include "bool.h"
+#include "StringA.h"
+#include "HistoryF.h"
 
 #include <X11/Intrinsic.h>
 
@@ -75,5 +77,18 @@ extern void goto_history(int pos = -1);
 // Invoke history dialog
 extern void gdbHistoryCB(Widget, XtPointer, XtPointer);
 
+// Tie a ComboBox to global history
+extern void tie_combo_box_to_history(Widget text, HistoryFilter filter);
+
+// Add FILE to recent file history
+extern void add_to_recent(const string& file);
+
+// Get recent file history (most recent first)
+extern void get_recent(StringArray& arr);
+
+// Tie a menu to recent files
+class MMDesc;
+extern void tie_menu_to_recent_files(MMDesc *items);
+
 #endif // _DDD_history_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
