@@ -1,23 +1,23 @@
-// $Id: options.h,v 1.31 1998/01/02 10:56:46 zeller Exp $ -*- C++ -*-
+// $Id: options.h,v 1.40 1998/05/21 17:37:22 zeller Exp $ -*- C++ -*-
 // Save and edit DDD options
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -64,20 +64,18 @@ bool saving_options_excludes_data(unsigned long flags);
 bool save_options(unsigned long flags);
 
 
-// Return true iff the startup preferences have changed.
-extern bool startup_preferences_changed();
-
 // Lots and lots of callbacks
 extern void sourceToggleFindWordsOnlyCB     (Widget, XtPointer, XtPointer);
 extern void sourceToggleFindCaseSensitiveCB (Widget, XtPointer, XtPointer);
 extern void sourceToggleCacheSourceFilesCB  (Widget, XtPointer, XtPointer);
 extern void sourceToggleCacheMachineCodeCB  (Widget, XtPointer, XtPointer);
-extern void sourceToggleDisassembleCB       (Widget, XtPointer, XtPointer);
 extern void sourceToggleAllRegistersCB      (Widget, XtPointer, XtPointer);
 extern void sourceToggleDisplayLineNumbersCB(Widget, XtPointer, XtPointer);
 extern void sourceSetDisplayGlyphsCB        (Widget, XtPointer, XtPointer);
 extern void sourceSetUseSourcePathCB        (Widget, XtPointer, XtPointer);
 extern void sourceSetTabWidthCB             (Widget, XtPointer, XtPointer);
+extern void sourceSetSourceIndentCB 	    (Widget, XtPointer, XtPointer);
+extern void sourceSetCodeIndentCB 	    (Widget, XtPointer, XtPointer);
 
 extern void graphToggleDetectAliasesCB      (Widget, XtPointer, XtPointer);
 extern void graphToggleAlign2dArraysCB      (Widget, XtPointer, XtPointer);
@@ -91,7 +89,7 @@ extern void graphSetGridSizeCB              (Widget, XtPointer, XtPointer);
 extern void dddToggleGroupIconifyCB         (Widget, XtPointer, XtPointer);
 extern void dddToggleUniconifyWhenReadyCB   (Widget, XtPointer, XtPointer);
 extern void dddToggleSeparateExecWindowCB   (Widget, XtPointer, XtPointer);
-extern void dddToggleUngrabMousePointerCB   (Widget, XtPointer, XtPointer);
+extern void dddToggleCheckGrabsCB           (Widget, XtPointer, XtPointer);
 extern void dddToggleSaveHistoryOnExitCB    (Widget, XtPointer, XtPointer);
 extern void dddToggleSuppressWarningsCB     (Widget, XtPointer, XtPointer);
 
@@ -100,6 +98,11 @@ extern void dddToggleValueTipsCB            (Widget, XtPointer, XtPointer);
 extern void dddToggleButtonDocsCB           (Widget, XtPointer, XtPointer);
 extern void dddToggleValueDocsCB            (Widget, XtPointer, XtPointer);
 
+extern void dddToggleButtonCaptionsCB       (Widget, XtPointer, XtPointer);
+extern void dddToggleButtonImagesCB         (Widget, XtPointer, XtPointer);
+extern void dddToggleFlatButtonsCB          (Widget, XtPointer, XtPointer);
+extern void dddToggleColorButtonsCB         (Widget, XtPointer, XtPointer);
+
 extern void dddSetGlobalTabCompletionCB     (Widget, XtPointer, XtPointer);
 extern void dddSetSeparateWindowsCB         (Widget, XtPointer, XtPointer);
 extern void dddSetStatusAtBottomCB          (Widget, XtPointer, XtPointer);
@@ -107,7 +110,7 @@ extern void dddSetToolBarCB                 (Widget, XtPointer, XtPointer);
 extern void dddSetKeyboardFocusPolicyCB     (Widget, XtPointer, XtPointer);
 extern void dddSetPannerCB                  (Widget, XtPointer, XtPointer);
 extern void dddSetDebuggerCB                (Widget, XtPointer, XtPointer);
-extern void dddSetStartupLogoCB             (Widget, XtPointer, XtPointer);
+extern void dddSetBindingStyleCB            (Widget, XtPointer, XtPointer);
 
 extern void dddSetEditCommandCB             (Widget, XtPointer, XtPointer);
 extern void dddSetGetCoreCommandCB          (Widget, XtPointer, XtPointer);
