@@ -1,23 +1,23 @@
-// $Id: session.h,v 1.12 1998/01/26 14:26:23 zeller Exp $ -*- C++ -*-
+// $Id: session.h,v 1.15 1998/05/21 18:32:40 zeller Exp $ -*- C++ -*-
 //
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -45,9 +45,6 @@ const string RESTART_SESSION = "." ddd_NAME;
 
 // Return session directories
 
-// Home directory ($HOME)
-string home_dir();
-
 // Root of DDD state (usually, `~/.ddd')
 string session_state_dir();
 
@@ -77,6 +74,11 @@ inline string session_log_file()
     return session_file(DEFAULT_SESSION, "log");
 }
 
+inline string session_tips_file()
+{
+    return session_file(DEFAULT_SESSION, "tips");
+}
+
 // Create session directory for SESSION; leave messages in MSG
 void create_session_dir(const string& session, ostream& msg);
 
