@@ -1,23 +1,23 @@
-// $Id: tabs.h,v 1.4 1997/10/03 10:41:49 zeller Exp $ -*- C++ -*-
+// $Id: tabs.h,v 1.6 1998/04/23 08:38:32 zeller Exp $ -*- C++ -*-
 // Tabulator functions
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
 // 
-// This file is part of the DDD Library.
+// This file is part of DDD.
 // 
-// The DDD Library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
+// DDD is free software; you can redistribute it and/or
+// modify it under the terms of the GNU General Public
 // License as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
 // 
-// The DDD Library is distributed in the hope that it will be useful,
+// DDD is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
-// See the GNU Library General Public License for more details.
+// See the GNU General Public License for more details.
 // 
-// You should have received a copy of the GNU Library General Public
-// License along with the DDD Library -- see the file COPYING.LIB.
+// You should have received a copy of the GNU General Public
+// License along with DDD -- see the file COPYING.
 // If not, write to the Free Software Foundation, Inc.,
 // 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
@@ -42,5 +42,12 @@ void tabto(string& s, int pos);
 // is reached; ignore first INDENT characters.
 void untabify(string& str, int tab_width = 8, int indent = 0);
 
+// Same, but untabify only for non-standard settings
+inline void untabify_if_needed(string& str, int tab_width = 8, int indent = 0)
+{
+    if (tab_width != 8 || indent % tab_width != 0)
+	untabify(str, tab_width, indent);
+}
+
 #endif // _DDD_tabs_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
